@@ -33,6 +33,7 @@ TEMPLATE_PATHS = [
 # config for example tree
 CONFIG = {
     "x": "foo",
+    "y": False,
     "database": {
     "url": "sqlite:///blah"
     }
@@ -90,6 +91,15 @@ class TestRunOSConfigApplier(testtools.TestCase):
                          self.stdout.read().strip())
         self.assertEqual('', self.logger.output)
 
+    def test_print_non_string_key(self):
+        self.assertEqual(0, apply_config.main(
+            ['os-apply-config.py', '--metadata', self.path, '--key',
+             'y', '--type', 'raw']))
+        self.stdout.seek(0)
+        self.assertEqual(str(CONFIG['y']),
+                         self.stdout.read().strip())
+        self.assertEqual('', self.logger.output)
+
     def test_print_key_missing(self):
         self.assertEqual(1, apply_config.main(
             ['os-apply-config.py', '--metadata', self.path, '--key',
